@@ -1,6 +1,7 @@
 # Framework constants
 FRAMEWORK_NAME = 'FRAMEWORK_NAME'
 ENVIRONMENT = "ENVIRONMENT"
+STATELESS = "STATELESS"
 
 # Database Constants
 DATABASE_CONFIG = 'DATABASE_CONFIG'
@@ -47,4 +48,6 @@ MARKET = "MARKET"
 TRACK_PORTFOLIO_FROM = "TRACK_PORTFOLIO_FROM"
 SQLITE_ENABLED = "SQLITE_ENABLED"
 PORTFOLIOS = "PORTFOLIOS"
+STRATEGIES = "STRATEGIES"
 APPLICATION_CONFIGURED = "APPLICATION_CONFIGURED"
+ACTION = "ACTION"
